/*
 * \brief  Utilities for XML
 * \author Norman Feske
 * \date   2018-01-11
 */

/*
 * Copyright (C) 2017-2019 Genode Labs GmbH
 *
 * This file is part of the Genode OS framework, which is distributed
 * under the terms of the GNU Affero General Public License version 3.
 */

#include <util/xml_node.h>

template <typename T>
static T _attribute_value(Genode::Xml_node const & node, char const *attr_name)
{
	return node.attribute_value(attr_name, T{});
}

template <typename T, typename... ARGS>
static T _attribute_value(Genode::Xml_node const & node, char const *sub_node_type, ARGS... args)
{
	if (!node.has_sub_node(sub_node_type))
		return T{};

	return _attribute_value<T>(node.sub_node(sub_node_type), args...);
}

/**
+ * Query attribute value from XML sub nodd
+ *
+ * The list of arguments except for the last one refer to XML path into the
+ * XML structure. The last argument denotes the queried attribute name.
+ */
template <typename T, typename... ARGS>
static T query_attribute(Genode::Xml_node const & node, ARGS &&... args)
{
	return _attribute_value<T>(node, args...);
}
